==> htsjdk_2.18.2+dfsg.orig.tar.xz: htsjdk-2.18.2/src/test/java/htsjdk/samtools/util/CigarElementUnitTest.java <==
package htsjdk.samtools.util;


import htsjdk.HtsjdkTest;
import htsjdk.samtools.CigarElement;
import htsjdk.samtools.CigarOperator;
import org.testng.Assert;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

public class CigarElementUnitTest extends HtsjdkTest {

    @Test(expectedExceptions = IllegalArgumentException.class)
    public void testNegativeLengthCheck(){
        final CigarElement element = new CigarElement(-1, CigarOperator.M);
    }


    @DataProvider
    public Object[][] elementsForEquals() {
        final CigarElement mElement = new CigarElement(10, CigarOperator.M);
        return new Object[][] {
                // same object
                {mElement, mElement, true},
                // different equal objects
                {mElement, new CigarElement(mElement.getLength(), mElement.getOperator()), true},
                // different lengths
                {mElement, new CigarElement(mElement.getLength() + 1, mElement.getOperator()), false},
                // different operators
                {mElement, new CigarElement(mElement.getLength(), CigarOperator.X), false},
                // different class
                {mElement, mElement.toString(), false}
        };
    }

    @Test(dataProvider = "elementsForEquals")
    public void testEqualsAndHashCode(final CigarElement element, final Object other, final boolean isEquals) {
        Assert.assertEquals(element.equals(other), isEquals);
        if (isEquals) {
            Assert.assertEquals(element.hashCode(), other.hashCode());
        }
    }
}

==> htsjdk_4.3.0+dfsg.orig.tar.xz: htsjdk-4.3.0/src/test/java/htsjdk/samtools/util/CigarElementUnitTest.java <==
package htsjdk.samtools.util;


import htsjdk.HtsjdkTest;
import htsjdk.samtools.CigarElement;
import htsjdk.samtools.CigarOperator;
import org.testng.Assert;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

public class CigarElementUnitTest extends HtsjdkTest {

    @Test(expectedExceptions = IllegalArgumentException.class)
    public void testNegativeLengthCheck(){
        new CigarElement(-1, CigarOperator.M);
    }


    @DataProvider
    public Object[][] elementsForEquals() {
        final CigarElement mElement = new CigarElement(10, CigarOperator.M);
        return new Object[][] {
                // same object
                {mElement, mElement, true},
                // different equal objects
                {mElement, new CigarElement(mElement.getLength(), mElement.getOperator()), true},
                // different lengths
                {mElement, new CigarElement(mElement.getLength() + 1, mElement.getOperator()), false},
                // different operators
                {mElement, new CigarElement(mElement.getLength(), CigarOperator.X), false},
                // different class
                {mElement, mElement.toString(), false}
        };
    }

    @Test(dataProvider = "elementsForEquals")
    public void testEqualsAndHashCode(final CigarElement element, final Object other, final boolean isEquals) {
        Assert.assertEquals(element.equals(other), isEquals);
        if (isEquals) {
            Assert.assertEquals(element.hashCode(), other.hashCode());
        }
    }
}
